@@ -11,6 +11,18 @@ p18b <- data.table(p18)
 setnames(p18b, c('OBS','PYRS','AGEGROUP'), c('obs','pyrs','agegroup'))
 wv <- c(.1,.1,.1,.2,.2,.2,.2,.3,.3,.4,.5,.5,.5,.4,.4,.3,.2,.1)
 
+# test_that("ratesplines", {
+#   library(data.table)
+#   library(splines)
+#   data <- ratesplines(data = p18, obs = 'OBS', pyrs = 'PYRS', print = 'COV', spline = 'AGEGROUP')
+#   
+# 
+#   
+#   
+#   
+# 
+# })
+
 test_that("rate works with different weights", {
   w1 <- rate(data = p18, obs = 'OBS', pyrs = 'PYRS', print = 'COV', adjust = 'AGEGROUP', weights = c(1:18))
   w2 <- rate(data = p20, obs = 'OBS', pyrs = 'PYRS', print = 'COV', adjust = 'AGEGROUP', weights = 'world_2000_20of5')
@@ -182,7 +194,10 @@ test_that("rate works with different weights and syntaxies", {
   s24a <- rate(data = p18, obs = 'OBS', pyrs = 'PYRS', adjust = list(AGEGROUP, COV), weights = "internal")
   s24b <- rate(data = p18, obs = 'OBS', pyrs = 'PYRS', adjust = c('AGEGROUP', 'COV'), weights = "internal")
   
-
+  ## update and getCall
+  s2B <- update(s0, adjust = factor(AGEGROUP, 1:18, 1:18), weights = wv)
+  expect_equal(data.table(s2B), data.table(s2))
+  
 })
 
 
